Getting started - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Getting started

## What are the benefits?

Tabler is a perfect solution if you want to create an interface which is not only user-friendly but also fully responsive. Thanks to the big choice of ready-made components, you can customize your design and adapt it to the needs of even the most demanding users. On top of that, Tabler is an open source solution, continuously developed and improved by the open source community.

## Set up the environment

To use our build system and run our documentation locally, you’ll need a copy of Tabler’s source files. Follow the steps below:

1. Install Node.js, which we use to manage our dependencies.
2. Navigate to the root `/tabler` directory and run `npm install` to install our local dependencies listed in `package.json`.
3. Install Ruby - the recommended version is 2.5.5.
4. Install Bundler with `gem install bundler` and, finally, run `bundle install`. It will install all Ruby dependencies, such as Jekyll and plugins.

### Windows users

1. Install Git in `C:\Program Files\git\bin` directory and run `npm config set script-shell "C:\Program Files\git\bin\bash.exe"` to change the default shell.
2. Install Ruby+Devkit - recommended version is 2.5.5.
3. Read guide to get Jekyll up and running without problems.

Once you’ve completed the setup, you’ll be able to run the various commands provided from the command line.

## Build Tabler locally

1. From the root `/tabler` directory, run `npm run start` in the command line.
2. Open http://localhost:3000 in your browser, and voilà.
3. Any change in `/src` directory will build the application and refresh the page.

## Bugs and feature requests

Found a bug or have a feature request? Please open a new issue.